==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ga.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Bainistigh Paraiméadair Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Bainistigh Gailearaí");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Méid Íomhá Leithead");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Méid Íomhá Airde");
define('MANAGE_GALLERY_THUMB_WIDTH', "Leithead Íomhá Mionsamhail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Mionsamhail Íomhá Airde");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Caomhnaigh Thumb Cóimheas Treoíochta");
define('MANAGE_GALLERY_SHOW_TITLES', "Taispeáin Teidil");
define('MANAGE_GALLERY_DISABLE_SORT', "Díchumasaigh Sórtáil");
define('MANAGE_GALLERY_DELETE_IMAGE', "Scrios Íomhá");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sábháil Sórtáil Ordú");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliceáil &#39;Nuashonraigh&#39; a fhoilsiú <br /> do íomhánna uaslódáil.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Gach íomhánna curtha athrú méide agus Sábháladh na socruithe.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Tharla earráid agus méid a athrú na n-íomhánna nó suímh a shábháil.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Tá do íomhá (í) uaslódáilte.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Tharla earráid agus uaslódáil do íomhá (í).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Níl an comhad a bhfuil tú ag iarraidh a uaslódáil íomhá.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Tá an comhad a bhfuil tú ag iarraidh a uaslódáil ró-mhór.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tá an teideal Sábháladh.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "An bhfuil tú cinnte gur mian leat an íomhá a scriosadh");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Tá an íomhá Scriosadh.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Tharla earráid agus scriosadh an íomhá.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "paraiméadair a shábháil agus íomhánna méid a athrú, thoil go fóill ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uaslódáil, le do thoil go fóill ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Níor chuir an sort &#39;Sábháladh. Ar mhaith leat a shábháil an t-ordú saghas?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Tá an sort &#39;íomhá Sábháladh.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tharla earráid agus an saghas íomhá.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ga.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Bainistigh Paraiméadair Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Bainistigh Gailearaí");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Méid Íomhá Leithead");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Méid Íomhá Airde");
define('MANAGE_GALLERY_THUMB_WIDTH', "Leithead Íomhá Mionsamhail");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Mionsamhail Íomhá Airde");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Caomhnaigh Thumb Cóimheas Treoíochta");
define('MANAGE_GALLERY_SHOW_TITLES', "Taispeáin Teidil");
define('MANAGE_GALLERY_DISABLE_SORT', "Díchumasaigh Sórtáil");
define('MANAGE_GALLERY_DELETE_IMAGE', "Scrios Íomhá");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sábháil Sórtáil Ordú");
define('MANAGE_GALLERY_PUBLISH_MSG', "Cliceáil &#39;Nuashonraigh&#39; a fhoilsiú <br /> do íomhánna uaslódáil.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Gach íomhánna curtha athrú méide agus Sábháladh na socruithe.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Tharla earráid agus méid a athrú na n-íomhánna nó suímh a shábháil.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Tá do íomhá (í) uaslódáilte.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Tharla earráid agus uaslódáil do íomhá (í).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Níl an comhad a bhfuil tú ag iarraidh a uaslódáil íomhá.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Tá an comhad a bhfuil tú ag iarraidh a uaslódáil ró-mhór.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tá an teideal Sábháladh.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "An bhfuil tú cinnte gur mian leat an íomhá a scriosadh");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Tá an íomhá Scriosadh.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Tharla earráid agus scriosadh an íomhá.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "paraiméadair a shábháil agus íomhánna méid a athrú, thoil go fóill ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uaslódáil, le do thoil go fóill ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Níor chuir an sort &#39;Sábháladh. Ar mhaith leat a shábháil an t-ordú saghas?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Tá an sort &#39;íomhá Sábháladh.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tharla earráid agus an saghas íomhá.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Tá an comhad a bhfuil tú ag iarraidh a uaslódáil níos mó ná an &#39;upload_max_filesize&#39; nó na socruithe PHP &#39;post_max_size&#39;. Déan teagmháil le riarthóir do chórais chun na teorainneacha seo a mhéadú.");
?>
